@@ -8,7 +8,11 @@ antipodal <- function(p1, p2) {
 	toRad <- pi / 180 
 	p1 <- .pointsToMatrix(p1) * toRad
 	p2 <- .pointsToMatrix(p2) * toRad
-	return( isTRUE(all.equal(p1[,2]+p2[,2], 0, check.attributes=FALSE)) & isTRUE(all.equal(abs(p1[,1]-p2[,1]), pi, check.attributes=FALSE)) ) 
+	p <- cbind(p1[,1], p1[,2], p2[,1], p2[,2])	
+	diflon = round(abs(p[,2] + p[,4]), 12)
+	diflat = round(abs(p[,1] - p[,3]) - pi, 12)
+	antipodal = (diflat == 0) & (diflon == 0)
+	return(antipodal)
 }
 
 
